==> MuSE-0.7pre1.tar.gz: MuSE-0.7pre1/gtkgui/icegui.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>
#include <stdlib.h>
#include <gtk/gtk.h>

#include <jutils.h>

#include "generic.h"
#include "profile.h"
#include "profilegui.h"
#include "icegui.h"

#include <jmixer.h>
#include <config.h>

GtkWidget *ice_new(GtkWidget *w)
{
	GtkWidget *tmplabel;
	struct icedata *i;
	
	i=(struct icedata *)malloc(sizeof(struct icedata));
	i->combi=NULL;
	/* FIXME: if I'd make two malloc for two struct icedata *, 
	 * I can use i without renaming it, and it's so tune for my mind!
	 */

	
/*	i->wice=gtk_window_new(GTK_WINDOW_TOPLEVEL); FIXME: remove i->wice
	gtk_container_set_border_width(GTK_CONTAINER(i->wice), 10);
	gtk_signal_connect(GTK_OBJECT(i->wice),"delete_event",
					(GtkSignalFunc)gtk_widget_destroy,NULL); 
	*/
	i->fram=gtk_frame_new("Let's connect! ");
/*	gtk_container_add(GTK_CONTAINER(i->wice), i->fram);*/
	/* FIXME: PULIAMO i MANNAGGIA ALL'AMICO DI DIO */	
	i->prin=gtk_vbox_new(FALSE, 10);
	gtk_container_set_border_width(GTK_CONTAINER(i->prin), 10);
	gtk_container_add(GTK_CONTAINER(i->fram), i->prin);

	i->three=gtk_hbox_new(FALSE, 4);
	gtk_container_add(GTK_CONTAINER(i->prin), i->three);

	/* creating three text entries with label (uff) ...
	 * FIXME: forse ci vorrebbe una tabella
	 * 		bisogna sistemare la massima lunghezza di testo 
	 * 		inseribile
	 */
	
	tmplabel=gtk_label_new("Host");
	gtk_box_pack_start(GTK_BOX(i->three), tmplabel, FALSE, FALSE, 0);
	i->host=gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(i->three), i->host, FALSE, FALSE, 0);

	tmplabel=gtk_label_new("Port");
	gtk_box_pack_start(GTK_BOX(i->three), tmplabel, FALSE, FALSE, 0);
	i->port=gtk_entry_new();
	gtk_widget_set_usize(GTK_WIDGET(i->port), 45, 22);
	gtk_box_pack_start(GTK_BOX(i->three), i->port, FALSE, FALSE, 0);

	tmplabel=gtk_label_new("Mnt");
	gtk_box_pack_start(GTK_BOX(i->three), tmplabel, FALSE, FALSE, 0);
	i->mnt=gtk_entry_new();
	gtk_widget_set_usize(GTK_WIDGET(i->mnt), 80, 22);
	gtk_box_pack_start(GTK_BOX(i->three), i->mnt, FALSE, FALSE, 0);

	i->two=gtk_hbox_new(FALSE, 4);
	gtk_container_add(GTK_CONTAINER(i->prin), i->two);

	tmplabel=gtk_label_new("Name");
	gtk_box_pack_start(GTK_BOX(i->two), tmplabel, FALSE, FALSE, 0);
	i->name=gtk_entry_new();
	gtk_widget_set_usize(GTK_WIDGET(i->name), 150, 22);
	gtk_box_pack_start(GTK_BOX(i->two), i->name, FALSE, FALSE, 0);
	
	tmplabel=gtk_label_new("Url");
	gtk_box_pack_start(GTK_BOX(i->two), tmplabel, FALSE, FALSE, 0);
	i->url=gtk_entry_new();
	/*gtk_widget_set_usize(GTK_WIDGET(i->url), 150, 22);*/
	gtk_box_pack_start(GTK_BOX(i->two), i->url, TRUE, TRUE, 0);

	i->one=gtk_hbox_new(FALSE,4);
	gtk_container_add(GTK_CONTAINER(i->prin), i->one);
	
	tmplabel=gtk_label_new("Description");
	gtk_box_pack_start(GTK_BOX(i->one), tmplabel, FALSE, FALSE, 0);
	i->desc=gtk_entry_new();
	gtk_widget_set_usize(GTK_WIDGET(i->desc), 300, 22);
	gtk_box_pack_start(GTK_BOX(i->one), i->desc, TRUE, TRUE, 0);

	i->last=gtk_hbox_new(FALSE, 4);
	gtk_container_add(GTK_CONTAINER(i->prin), i->last);
	
	tmplabel=gtk_label_new("Login Type");
	gtk_box_pack_start(GTK_BOX(i->last), tmplabel, FALSE, FALSE, 0);
	i->logintype=gtk_combo_new();
	i->combi=g_list_append(i->combi, (void *) "x-audiocast");
	i->combi=g_list_append(i->combi, (void *) "icy");
	gtk_combo_set_popdown_strings(GTK_COMBO(i->logintype), i->combi);
	gtk_widget_set_usize(GTK_WIDGET(i->logintype), 100, 22);
	gtk_box_pack_start(GTK_BOX(i->last), i->logintype, FALSE, FALSE, 0);

	tmplabel=gtk_label_new("Pass");
	gtk_box_pack_start(GTK_BOX(i->last), tmplabel, FALSE, FALSE, 0);
	i->pass=gtk_entry_new();
/*	gtk_widget_set_usize(GTK_WIDGET(i->pass), 80, 22);*/
	gtk_entry_set_visibility(GTK_ENTRY(i->pass), FALSE);
	gtk_box_pack_start(GTK_BOX(i->last), i->pass, TRUE, TRUE, 0);
	
	i->last=gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(i->prin), i->last, FALSE, FALSE, 0);
	
	tmplabel=gtk_button_new_with_label("Browse Profile...");
	gtk_object_set_data(GTK_OBJECT(tmplabel), "type", (void *) "icecast");
	gtk_signal_connect(GTK_OBJECT(tmplabel), "clicked",
			(GtkSignalFunc)profile_new, i);
	gtk_box_pack_start(GTK_BOX(i->last), tmplabel, TRUE, TRUE, 0); 
	
	tmplabel=gtk_button_new_with_label("Save profile...");
	gtk_object_set_data(GTK_OBJECT(tmplabel), "type", (void *) "icecast");
	gtk_signal_connect(GTK_OBJECT(tmplabel), "clicked",
			(GtkSignalFunc) profile_save, i);
	gtk_box_pack_start(GTK_BOX(i->last), tmplabel, TRUE, TRUE, 0);
	/* sistemare gli event con i segnali */
	i->conn=gtk_toggle_button_new_with_label("Connect");
	if(mixer->icecastout)
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(i->conn), TRUE);
	gtk_signal_connect(GTK_OBJECT(i->conn), "clicked", 
			(GtkSignalFunc) gcb_set_icecast, i);
/*	gtk_widget_set_usize(GTK_WIDGET(i->conn), 60, 22); */
	gtk_box_pack_start(GTK_BOX(i->last), i->conn, TRUE, TRUE, 0);
	
	if(icetmp->status) 
		ice_put(i);
	

	return i->fram;

	/*TODO:
	   waiting for connect ... (I mean progress bar) */
}

void ice_put(struct icedata *i) 
{
	
	gtk_entry_set_text(GTK_ENTRY(i->host), icetmp->ip);
	gtk_entry_set_text(GTK_ENTRY(i->port), icetmp->port);
	gtk_entry_set_text(GTK_ENTRY(i->mnt), icetmp->mnt);
	gtk_entry_set_text(GTK_ENTRY(i->name), icetmp->name);
	gtk_entry_set_text(GTK_ENTRY(i->url), icetmp->url);
	gtk_entry_set_text(GTK_ENTRY(i->desc), icetmp->desc);
	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(i->logintype)->entry),
			icetmp->login);
}

void ice_get(struct icedata *i)
{
	icetmp->ip= strdup(gtk_entry_get_text(GTK_ENTRY(i->host)));
	icetmp->port= strdup(gtk_entry_get_text(GTK_ENTRY(i->port)));
	icetmp->mnt= strdup(gtk_entry_get_text(GTK_ENTRY(i->mnt)));
	icetmp->url= strdup(gtk_entry_get_text(GTK_ENTRY(i->url)));
	icetmp->name= strdup(gtk_entry_get_text(GTK_ENTRY(i->name)));
	icetmp->desc= strdup(gtk_entry_get_text(GTK_ENTRY(i->desc)));
	icetmp->login= strdup(gtk_entry_get_text(GTK_ENTRY(
				GTK_COMBO(i->logintype)->entry)));
	icetmp->pass= strdup(gtk_entry_get_text(GTK_ENTRY(i->pass)));

	if(!(strcmp(icetmp->login,"x-audiocast")))
		icetmp->logtype=0;
	else
		icetmp->logtype=1;
	
	icetmp->nport=atoi(icetmp->port);
	icetmp->status=true;
}

void gcb_set_icecast(GtkWidget *w, struct icedata *i)
{
	if(!lametmp->status) { 
		/* is encoder configured? */
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FALSE);
		func("gcb_set_icecast:: must configure the encoder first");
		gtk_notebook_set_page(GTK_NOTEBOOK(nbook), 1);
		return;
	}
	
	if( lametmp->status && (GTK_TOGGLE_BUTTON(w)->active)) {
	  //		profile_free_ice(icetmp);
		profile_init_ice(&icetmp);

		ice_get(i);
				
		if((mixer->set_icecast(icetmp->ip, icetmp->nport, icetmp->pass, 
				       icetmp->mnt, guibitrate, icetmp->name,
				       icetmp->url, icetmp->desc, icetmp->logtype))) {
			gtk_window_set_title(GTK_WINDOW(winil), "Connected");
			//			profile_put_ice("last", icetmp);
		} else {
			gtk_window_set_title(GTK_WINDOW(winil), "Connection failed");
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FALSE);
		}
	}
	else
		if(mixer->icecastout)
			mixer->stop_icecast();
}

void gcb_ice_get(GtkWidget *w, gint row, gint column, GdkEventButton *s, 
		struct icedata *i)
{
	bool res=false;
	gchar *str=NULL;
	
	i->riga=row;

	func("gcb_ice_get(%p, %d, %d, %p)", w, row, column, s);
	gtk_clist_get_text(GTK_CLIST(w), row, column, &str);
	func("gcb_ice_get:: selected %s profile", str);
	act("gcb_ice_get:: going to config for %s", str);

	res=profile_get_ice(str, icetmp);
	if(!res) {
		error("gcb_ice_get:: we got an error in profile_get_ice");
		return;
	}
}

void gcb_ice_put(GtkWidget *w, struct icedata *i)
{
	ice_put(i);
}

void gcb_ice_save(GtkWidget *w, GtkWidget *e)
{
	char *profile=NULL;
	
	profile=gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(e)->entry));
	
	if(profile[0] == ' ') {
		warning("gcb_ice_save:: you should insert a filename");
		return;
	}
	profile_put_ice(profile, icetmp);
	gtk_widget_destroy(GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(w), 
					"window")));
}

void gcb_ice_rem(GtkWidget *w, struct icedata *i)
{
	char profile[100];
	char profdef[100];

	/* quale ricchione di merda ha scritto questo codice profile non
	 * e' NULLA */	
	if(!icetmp->profile) {
		warning("gcb_ice_rem:: sorry no profile selected");
		return;
	}

	if(strstr(profile_get_default("icecast"), icetmp->profile)) {
		snprintf(profdef, sizeof(profdef), "icecastdefault=%s", 
				icetmp->profile);
		profile_remove(profdef);
	}
	
	func("gcb_ice_rem:: removing profile %s", icetmp->profile);
	snprintf(profile, sizeof(profile), "[icecast=%s]", icetmp->profile);

	profile_remove(profile);
	if(i->riga != -1) {
		gtk_clist_remove(GTK_CLIST(i->lista), i->riga);
		i->riga=-1;
	} else
		warning("gcb_ice_rem:: I'm sorry, you have to select a profile before");
}

void gcb_ice_default(GtkWidget *w, struct icedata *i)
{
	char *text=NULL;

	if(i->riga==-1)
		return;

	if(GTK_TOGGLE_BUTTON(w)->active) {
	gtk_clist_get_text(GTK_CLIST(i->lista), i->riga, 0, &text);
	profile_put_default("icecast", text);
	}

}

==> MuSE-0.7.2.tar.gz: MuSE-0.7.2/gtkgui/icegui.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>
#include <stdlib.h>
#include <gtk/gtk.h>

#include <jutils.h>

#include "generic.h"
#include <profilegui.h>
#include <icegui.h>


#include <jmixer.h>
#include <config.h>

GtkWidget *ice_new(GtkWidget *w)
{
	GtkWidget *tmplabel;
	struct icedata *i;

	/* FIXME: I malloc, but not free */
	i=(struct icedata *)malloc(sizeof(struct icedata));
	i->combi=NULL;

	i->fram=gtk_frame_new("Let's connect! ");
	
	i->prin=gtk_vbox_new(FALSE, 10);
	gtk_container_set_border_width(GTK_CONTAINER(i->prin), 10);
	gtk_container_add(GTK_CONTAINER(i->fram), i->prin);

	i->three=gtk_hbox_new(FALSE, 4);
	gtk_container_add(GTK_CONTAINER(i->prin), i->three);

	tmplabel=gtk_label_new("Host");
	gtk_box_pack_start(GTK_BOX(i->three), tmplabel, FALSE, FALSE, 0);
	i->host=gtk_entry_new_with_max_length(MAX_OPTION_SIZE);
	gtk_box_pack_start(GTK_BOX(i->three), i->host, FALSE, FALSE, 0);

	tmplabel=gtk_label_new("Port");
	gtk_box_pack_start(GTK_BOX(i->three), tmplabel, FALSE, FALSE, 0);
	i->port=gtk_entry_new_with_max_length(MAX_OPTION_SIZE);
	gtk_widget_set_usize(GTK_WIDGET(i->port), 45, 22);
	gtk_box_pack_start(GTK_BOX(i->three), i->port, FALSE, FALSE, 0);

	tmplabel=gtk_label_new("Mnt");
	gtk_box_pack_start(GTK_BOX(i->three), tmplabel, FALSE, FALSE, 0);
	i->mnt=gtk_entry_new_with_max_length(MAX_OPTION_SIZE);
	gtk_widget_set_usize(GTK_WIDGET(i->mnt), 80, 22);
	gtk_box_pack_start(GTK_BOX(i->three), i->mnt, FALSE, FALSE, 0);

	i->two=gtk_hbox_new(FALSE, 4);
	gtk_container_add(GTK_CONTAINER(i->prin), i->two);

	tmplabel=gtk_label_new("Name");
	gtk_box_pack_start(GTK_BOX(i->two), tmplabel, FALSE, FALSE, 0);
	i->name=gtk_entry_new_with_max_length(MAX_OPTION_SIZE);
	gtk_widget_set_usize(GTK_WIDGET(i->name), 150, 22);
	gtk_box_pack_start(GTK_BOX(i->two), i->name, FALSE, FALSE, 0);
	
	tmplabel=gtk_label_new("Url");
	gtk_box_pack_start(GTK_BOX(i->two), tmplabel, FALSE, FALSE, 0);
	i->url=gtk_entry_new_with_max_length(MAX_OPTION_SIZE);
	/*gtk_widget_set_usize(GTK_WIDGET(i->url), 150, 22);*/
	gtk_box_pack_start(GTK_BOX(i->two), i->url, TRUE, TRUE, 0);

	i->one=gtk_hbox_new(FALSE,4);
	gtk_container_add(GTK_CONTAINER(i->prin), i->one);
	
	tmplabel=gtk_label_new("Description");
	gtk_box_pack_start(GTK_BOX(i->one), tmplabel, FALSE, FALSE, 0);
	i->desc=gtk_entry_new_with_max_length(MAX_OPTION_SIZE);
	gtk_widget_set_usize(GTK_WIDGET(i->desc), 300, 22);
	gtk_box_pack_start(GTK_BOX(i->one), i->desc, TRUE, TRUE, 0);

	i->last=gtk_hbox_new(FALSE, 4);
	gtk_container_add(GTK_CONTAINER(i->prin), i->last);
	
	tmplabel=gtk_label_new("Login Type");
	gtk_box_pack_start(GTK_BOX(i->last), tmplabel, FALSE, FALSE, 0);
	i->logintype=gtk_combo_new();
	i->combi=g_list_append(i->combi, (void *) "x-audiocast");
	i->combi=g_list_append(i->combi, (void *) "icy");
	gtk_combo_set_popdown_strings(GTK_COMBO(i->logintype), i->combi);
	gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(i->logintype)->entry), FALSE);
	gtk_widget_set_usize(GTK_WIDGET(i->logintype), 100, 22);
	gtk_box_pack_start(GTK_BOX(i->last), i->logintype, FALSE, FALSE, 0);

	tmplabel=gtk_label_new("Pass");
	gtk_box_pack_start(GTK_BOX(i->last), tmplabel, FALSE, FALSE, 0);
	i->pass=gtk_entry_new_with_max_length(MAX_OPTION_SIZE);
/*	gtk_widget_set_usize(GTK_WIDGET(i->pass), 80, 22);*/
	gtk_entry_set_visibility(GTK_ENTRY(i->pass), FALSE);
	gtk_box_pack_start(GTK_BOX(i->last), i->pass, TRUE, TRUE, 0);
	
	i->last=gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(i->prin), i->last, FALSE, FALSE, 0);
	
	tmplabel=gtk_button_new_with_label("Browse Profile...");
	gtk_object_set_data(GTK_OBJECT(tmplabel), "type", (void *) "ice");
	gtk_signal_connect(GTK_OBJECT(tmplabel), "clicked",
			(GtkSignalFunc)profile_new, i);
	gtk_box_pack_start(GTK_BOX(i->last), tmplabel, TRUE, TRUE, 0); 
	
	tmplabel=gtk_button_new_with_label("Save profile...");
	gtk_object_set_data(GTK_OBJECT(tmplabel), "type", (void *) "ice");
	gtk_signal_connect(GTK_OBJECT(tmplabel), "clicked",
			(GtkSignalFunc) profile_save, i);
	gtk_box_pack_start(GTK_BOX(i->last), tmplabel, TRUE, TRUE, 0);
	/* sistemare gli event con i segnali */
	i->conn=gtk_toggle_button_new_with_label("Connect");
	if(mixer->icecastout)
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(i->conn), TRUE);
	gtk_signal_connect(GTK_OBJECT(i->conn), "clicked", 
			(GtkSignalFunc) gcb_set_icecast, i);
/*	gtk_widget_set_usize(GTK_WIDGET(i->conn), 60, 22); */
	gtk_box_pack_start(GTK_BOX(i->last), i->conn, TRUE, TRUE, 0);

	/* is the first time? then pick up values from core */
	if(firstice)
		firstice=false;
	else
		mixer->ice.load_profile("last_active");
	ice_put(i); 
	

	return i->fram;

	/*TODO:
	   waiting for connect ... (I mean progress bar) */
}

void ice_free(void)
{
	if(icetmp.status) {
		g_free(icetmp.ip);
		g_free(icetmp.mnt);
		g_free(icetmp.pass);
		g_free(icetmp.name);
		g_free(icetmp.url);
		g_free(icetmp.desc);
		g_free(icetmp.login);
	}
}

void ice_put(struct icedata *i) 
{
	char tmp[MAX_VALUE_SIZE];

	/* clean up */
	ice_free();
	/* syncing with muse-core */
	icetmp.ip = strdup(mixer->ice.ip);
	icetmp.mnt = strdup(mixer->ice.mount);
	icetmp.pass = strdup(mixer->ice.pass);
	icetmp.name = strdup(mixer->ice.name);
	icetmp.url = strdup(mixer->ice.url);
	icetmp.desc = strdup(mixer->ice.desc);

	icetmp.port = mixer->ice.port;
	icetmp.logtype= mixer->ice.login;
	
	switch(icetmp.logtype) {
		case 0:
			icetmp.login = strdup("x-audiocast");
			break;
		case 1:
			icetmp.login = strdup("icy");
			break;
	}
	icetmp.status=true;

	/* fill GUI */
	snprintf(tmp, MAX_VALUE_SIZE,"%d", icetmp.port);
	gtk_entry_set_text(GTK_ENTRY(i->host), icetmp.ip);
	gtk_entry_set_text(GTK_ENTRY(i->port), tmp);
	gtk_entry_set_text(GTK_ENTRY(i->mnt), icetmp.mnt);
	gtk_entry_set_text(GTK_ENTRY(i->name), icetmp.name);
	gtk_entry_set_text(GTK_ENTRY(i->url), icetmp.url);
	gtk_entry_set_text(GTK_ENTRY(i->desc), icetmp.desc);
	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(i->logintype)->entry),
			icetmp.login);
}

void ice_get(struct icedata *i)
{

	ice_free();

	icetmp.ip= gtk_editable_get_chars(GTK_EDITABLE(i->host), 0, -1);
	icetmp.port= atoi(gtk_editable_get_chars(GTK_EDITABLE(i->port), 0, -1));
	icetmp.mnt= gtk_editable_get_chars(GTK_EDITABLE(i->mnt), 0, -1);
	icetmp.url= gtk_editable_get_chars(GTK_EDITABLE(i->url), 0, -1);
	icetmp.name= gtk_editable_get_chars(GTK_EDITABLE(i->name), 0, -1);
	icetmp.desc= gtk_editable_get_chars(GTK_EDITABLE(i->desc), 0, -1);
	icetmp.login= gtk_editable_get_chars(GTK_EDITABLE(
				GTK_COMBO(i->logintype)->entry), 0, -1);
	icetmp.pass= gtk_editable_get_chars(GTK_EDITABLE(i->pass), 0, -1);

	if(!(strcmp(icetmp.login,"x-audiocast")))
		icetmp.logtype=0;
	else
		icetmp.logtype=1;
	
	icetmp.status=true;
	
}

void gcb_set_icecast(GtkWidget *w, struct icedata *i)
{
/*	if(!lametmp->status) { 
		is encoder configured? 
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FALSE);
		func("gcb_set_icecast:: must configure the encoder first");
		gtk_notebook_set_page(GTK_NOTEBOOK(nbook), 1);
		return;
	}
	*/
	if((GTK_TOGGLE_BUTTON(w)->active)) {

		ice_get(i);
				
		if((mixer->set_icecast(icetmp.ip, icetmp.port, icetmp.pass, 
				       icetmp.mnt, icetmp.name, icetmp.url,
					   icetmp.desc, icetmp.logtype))) {
			gtk_window_set_title(GTK_WINDOW(winil), "Connected");
		} else {
			gtk_window_set_title(GTK_WINDOW(winil), "Connection failed");
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FALSE);
		}
	}
	else
		if(mixer->icecastout)
			mixer->stop_icecast();
}

void gcb_ice_get(GtkWidget *w, gint row, gint column, GdkEventButton *s, 
		struct icedata *i)
{
	gchar *str=NULL;
	
	i->riga=row;

	func("gcb_ice_get(%p, %d, %d, %p)", w, row, column, s);
	gtk_clist_get_text(GTK_CLIST(w), row, column, &str);
	func("gcb_ice_get:: selected %s profile", str);
	
	/* load profile and save old one */
	mixer->ice.load_profile(str);
	
}

void gcb_ice_put(GtkWidget *w, struct icedata *i)
{
	ice_put(i);
}

void gcb_ice_save(GtkWidget *w, GtkWidget *e)
{
	char *profile=NULL;
	
	profile=gtk_editable_get_chars(GTK_EDITABLE(GTK_COMBO(e)->entry), 0, -1);
	
	if(profile[0] == ' ') {
		warning("gcb_ice_save:: you should insert a filename");
		return;
	}
	/* load values and then write profile */	
	/* FIXME: set max size of gtk_entry */
	strcpy(mixer->ice.ip, icetmp.ip);
	strcpy(mixer->ice.mount, icetmp.mnt);
	strcpy(mixer->ice.pass, icetmp.pass);
	strcpy(mixer->ice.name, icetmp.name);
	strcpy(mixer->ice.url, icetmp.url);
	strcpy(mixer->ice.desc, icetmp.desc);

	mixer->ice.port = icetmp.port;
	mixer->ice.login = icetmp.logtype;
	
	mixer->ice.write_profile(profile);
	g_free(profile);
	gtk_widget_destroy(GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(w), 
					"window")));
}

void gcb_ice_rem(GtkWidget *w, struct icedata *i)
{
/*	char profile[100];
	char profdef[100];

	if(!icetmp->profile) {
		warning("gcb_ice_rem:: sorry no profile selected");
		return;
	}

	if(strstr(profile_get_default("icecast"), icetmp->profile)) {
		snprintf(profdef, sizeof(profdef), "icecastdefault=%s", 
				icetmp->profile);
		profile_remove(profdef);
	}
	
	func("gcb_ice_rem:: removing profile %s", icetmp->profile);
	snprintf(profile, sizeof(profile), "[icecast=%s]", icetmp->profile);

	profile_remove(profile);
	if(i->riga != -1) {
		gtk_clist_remove(GTK_CLIST(i->lista), i->riga);
		i->riga=-1;
	} else
		warning("gcb_ice_rem:: I'm sorry, you have to select a profile before");
		*/
}

void gcb_ice_default(GtkWidget *w, struct icedata *i)
{
	char *text=NULL;

	if(i->riga==-1)
		return;

	if(GTK_TOGGLE_BUTTON(w)->active) {
	gtk_clist_get_text(GTK_CLIST(i->lista), i->riga, 0, &text);
	mixer->ice.load_profile(text);
	mixer->ice.write_profile("default");
	}

}
